;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "wordcount-section" "20251029.1934"
  "Universal Sidecar Section to show Word Counts."
  '((emacs             "28.1")
    (compat            "29.1")
    (universal-sidecar "1.5.1"))
  :url "https://git.sr.ht/~swflint/emacs-universal-sidecar"
  :commit "01b12aecca0ce66f5427e7fe65012d37e7e128b2"
  :revdesc "01b12aecca0c"
  :keywords '("text" "convenience")
  :authors '(("Samuel W. Flint" . "me@samuelwflint.com"))
  :maintainers '(("Samuel W. Flint" . "me@samuelwflint.com")))
